@@ -6,9 +6,11 @@ import re
 import pytest
 
 from bidsphysio.dcm2bids import dcm2bidsphysio as d2bp
+from bidsphysio.base.bidsphysio import PhysioData
 from bidsphysio.base.utils import (check_bidsphysio_outputs,
                                    get_physio_TRs)
-from .utils import TESTS_DATA_PATH
+from .utils import (TESTS_DATA_PATH,
+                    EXPECTED_ACQ_TIME)
 
 '''
 TO-DO:
@@ -34,7 +36,7 @@ def mock_dcm2bidsphysio(monkeypatch):
 
     def mock_dcm2bids(*args, **kwargs):
         print('mock_dcm2bids called')
-        return
+        return PhysioData()
 
     monkeypatch.setattr(d2bp, "dcm2bids", mock_dcm2bids)
 
@@ -83,6 +85,12 @@ def test_main_args(
     assert d2bp.main() is None
 
 
+def test_get_acq_time():
+    """   Test for get_acq_time   """
+    for f in TESTS_DATA_PATH.glob('*.log'):
+        assert d2bp.get_acq_time(f) == EXPECTED_ACQ_TIME
+
+
 def test_parse_log():
     """   Test for parse_log   """
 
@@ -105,8 +113,9 @@ def test_parse_log():
 
     # generate a string, line-by-line, and parse it:
     physio_log_lines = simulated_string.splitlines()
-    waveform_name, t, s, dt = d2bp.parse_log(physio_log_lines)
+    uuid, waveform_name, t, s, dt = d2bp.parse_log(physio_log_lines)
 
+    assert uuid == expected_uuid
     assert waveform_name == expected_LogDataType
     assert all(t == [2.5 * e for e in expected_times])    # the "SampleTime" is in units of 2.5 ms
     assert all(s == expected_signals)
@@ -130,7 +139,7 @@ def test_parse_log():
 
     # generate a string, line-by-line, and parse it:
     physio_log_lines = simulated_string.splitlines()
-    waveform_name, t, s, dt = d2bp.parse_log(physio_log_lines)
+    uuid, waveform_name, t, s, dt = d2bp.parse_log(physio_log_lines)
 
     assert waveform_name == expected_LogDataType
     assert all(t == [2.5 * e for e in expected_times])    # the "SampleTime" is in units of 2.5 ms
